setAudioMute method

Future<void> setAudioMute(
  1. bool mute
)

Sets whether audio playback defined by AHAP files should be muted.

When audio is muted, calls to play and playAHAP will not produce any audio playback, and ongoing audio playback will be stopped.

This applies exclusively to audio playback defined by AHAP files.

mute - Whether to mute audio playback defined by AHAP files.

Returns a Future that completes when the mute setting has been applied.

Implementation

Future<void> setAudioMute(bool mute) {
  return HapticlabsPlayerPlatform.instance.setAudioMute(mute);
}