setHapticsMute method
Sets whether haptics defined by AHAP files should be muted.
When haptics are muted, calls to play and playAHAP will not produce
any haptic feedback, and ongoing haptic feedback will be stopped.
This applies exclusively to haptics defined by AHAP files; predefined
haptic effects played via playPredefinedHaptics are not affected.
Audio playback defined by AHAP files is not affected by this setting.
mute - Whether to mute haptics defined by AHAP files.
Returns a Future that completes when the mute setting has been applied.
Implementation
Future<void> setHapticsMute(bool mute) {
return HapticlabsPlayerPlatform.instance.setHapticsMute(mute);
}